@@ -2,7 +2,7 @@
 
 ##############################################################
 ##   smscon-editor  -  Configuration UI for the SMSCON      ##
-# $Id: smsconEditorMain.py 38 2011-12-18 11:01:16Z saturn $
+# $Id: smsconEditorMain.py 42 2011-12-18 17:11:03Z saturn $
 ##############################################################
 # Copyright (c) 2010-2011 Christos Zamantzas
 # Licenced under GPLv2
@@ -10,7 +10,7 @@
 #Author: Christos Zamantzas <christos.zamantzas@gmail.com>
 #Contributions: Frank Visser - import, decrypt and encrypt from config file the user variables.
 #Contributions: Lutz Schwarz - refacturing to use common code in smsconlib.py
-Version = '0.9.3-1'
+Version = '0.9.4-1'
 
 import os
 import sys
@@ -107,7 +107,7 @@ def configTrue(yesNoValue):
 def IsPasswordValid(password):  ### FIXME: what should be the behaviour if password is missing or empty?
     '''
     Check the given password.
-    @return bool True iff password is valid (may terminate app on hack detection).
+    @return bool True if password is valid (may terminate app on hack detection).
     '''
 
     try:
